#include-once
#include <File.au3>

;====================================================================================================================
; Name              : _ArrayFileToArray
; Description       : Put an array file to an array
; Syntax            : _ArrayFileToArray($hFile, $vDelimeter, $EmptyLine)
; Parameter(s)      : $hFile - The file to proceed.
;                     $vDelimeter - One or more characters to use as delimiters (case sensitive)(Default is ';').
;                     $EmptyLine -	0 Do not return empty lines (Default).
;									1 Return the empty lines.
;                     $IndexBase -	0 Return an array that begin in index 0 (Default).
;									1 Return an array that begin in line 1 with elements numbers in index 0.
; Requirement(s)    : File.au3
; Return value(s)   : On Success - Returns array of file
;                     On Failure - Returns 0
; Author            : Tlem <tlem at tuxolem dot fr>
; Note(s)           : Inspired from a function made by SmOke_N
; 					  http://www.autoitscript.com/forum/index.php?showtopic=26544&view=findpost&p=187403
; ====================================================================================================================
Func _ArrayFileToArray($hFile, $vDelimeter = ';', $EmptyLine = 0, $IndexBase = 0)
	Local $aArray = '', $iMaxElement = 0, $iEmptyLines = 0, $iSecondElement = 0, $avArrayCount = 0
	If Not _FileReadToArray($hFile, $aArray) Then Return 0
	If $iEmptyLines <> 0 Then $iEmptyLines = 1
	If $IndexBase <> 0 Then $IndexBase = 1
	For $iLinesCount = 1 To $aArray[0]
		If $aArray[$iLinesCount] <> '' Then
			$iSecondElement = UBound(StringSplit($aArray[$iLinesCount], $vDelimeter, 1) - 1) - 1
			If $iSecondElement > $iMaxElement Then $iMaxElement = $iSecondElement
		EndIf
	Next

	If $EmptyLine = 0 Then
		For $iLinesCount = 1 To $aArray[0]
			If $aArray[$iLinesCount] = '' Then $iEmptyLines += 1
		Next
	EndIf

	Local $avArray[$aArray[0] - $iEmptyLines + $IndexBase][$iMaxElement]


	For $iCount = 1 To $aArray[0]
		If $EmptyLine = 1 Then
			$avArrayCount += 1
			$aSplit = StringSplit($aArray[$iCount], $vDelimeter)
			If $aSplit[0] - 1 > 0 Then
				For $iCount2 = 1 To $aSplit[0]
					$avArray[$avArrayCount - 1 + $IndexBase][$iCount2 - 1] = $aSplit[$iCount2]
				Next
			EndIf
		ElseIf $aArray[$iCount] <> '' Then
			$avArrayCount += 1
			$aSplit = StringSplit($aArray[$iCount], $vDelimeter, 1)
			If $aSplit[0] - 1 > 0 Then
				For $iCount2 = 1 To $aSplit[0]
					$avArray[$avArrayCount - 1 + $IndexBase][$iCount2 - 1] = $aSplit[$iCount2]
				Next
			EndIf
		EndIf
	Next
	If $IndexBase = 1 Then $avArray[0][0] = $avArrayCount
	Return $avArray
EndFunc   ;==>_ArrayFileToArray
